==> tw-api-5.0.51-20240717.100821-1-sources.jar: com/elitesland/tw/tw5/api/prd/borrow/service/BorrowWriteOffService.java <==
package com.elitesland.tw.tw5.api.prd.borrow.service;

import com.elitesland.tw.tw5.api.prd.borrow.payload.BorrowWriteOffPayload;
import com.elitesland.tw.tw5.api.prd.borrow.query.BorrowWriteOffQuery;
import com.elitesland.tw.tw5.api.prd.borrow.vo.BorrowWriteOffVO;
import com.elitescloud.cloudt.common.base.PagingVO;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 借款核销
 *
 * @author wangly
 * @date 2024-07-15
 */
public interface BorrowWriteOffService {

    /**
     * 分页列表
     *
     * @param query 条件
     * @return {@link PagingVO}<{@link BorrowWriteOffVO}>
     */
    PagingVO<BorrowWriteOffVO> queryPaging(BorrowWriteOffQuery query);

    /**
     * 查询列表
     *
     * @param query 条件参数
     * @return {@link List}<{@link BorrowWriteOffVO}>
     */
    List<BorrowWriteOffVO> queryListDynamic(BorrowWriteOffQuery query);

    /**
     * 通过主键查询
     *
     * @param key 主键
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO queryByKey(Long key);

    /**
     * 新增
     *
     * @param payload 单据数据
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO insert(BorrowWriteOffPayload payload);

    /**
     * 修改
     *
     * @param payload 单据数据
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO update(BorrowWriteOffPayload payload);

    /**
     * 修改,置空的字段需需要借助 protected List<String> nullFields;
     *
     * @param payload 单据数据
     * @return {@link long}
     */
    long updateByKeyDynamic(BorrowWriteOffPayload payload);

    /**
     * 逻辑删除
     *
     * @param keys 主键集合
     */
    void deleteSoft(List<Long> keys);

}

==> tw-api-5.0.82-20240723.105238-2-sources.jar: com/elitesland/tw/tw5/api/prd/borrow/service/BorrowWriteOffService.java <==
package com.elitesland.tw.tw5.api.prd.borrow.service;

import com.elitesland.tw.tw5.api.prd.borrow.payload.BorrowWriteOffPayload;
import com.elitesland.tw.tw5.api.prd.borrow.query.BorrowWriteOffQuery;
import com.elitesland.tw.tw5.api.prd.borrow.vo.BorrowMoneyVO;
import com.elitesland.tw.tw5.api.prd.borrow.vo.BorrowWriteOffVO;
import com.elitescloud.cloudt.common.base.PagingVO;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 借款核销
 *
 * @author wangly
 * @date 2024-07-15
 */
public interface BorrowWriteOffService {

    /**
     * 分页列表
     *
     * @param query 条件
     * @return {@link PagingVO}<{@link BorrowWriteOffVO}>
     */
    PagingVO<BorrowWriteOffVO> queryPaging(BorrowWriteOffQuery query);

    /**
     * 查询列表
     *
     * @param query 条件参数
     * @return {@link List}<{@link BorrowWriteOffVO}>
     */
    List<BorrowWriteOffVO> queryListDynamic(BorrowWriteOffQuery query);

    /**
     * 通过主键查询
     *
     * @param key 主键
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO queryByKey(Long key);

    /**
     * 新增
     *
     * @param payload 单据数据
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO insert(BorrowWriteOffPayload payload);

    /**
     * 修改
     *
     * @param payload 单据数据
     * @return {@link BorrowWriteOffVO}
     */
    BorrowWriteOffVO update(BorrowWriteOffPayload payload);

    /**
     * 修改,置空的字段需需要借助 protected List<String> nullFields;
     *
     * @param payload 单据数据
     * @return {@link long}
     */
    long updateByKeyDynamic(BorrowWriteOffPayload payload);

    /**
     * 逻辑删除
     *
     * @param keys 主键集合
     */
    void deleteSoft(List<Long> keys);

    /**
     * 通过报销id查询借款列表
     *
     * @param reimId 报销id
     */
    List<BorrowMoneyVO>  queryByReimId(Long reimId);

    /**
     * 通过报销id删除核销数据
     *
     * @param reimId 报销id
     */
    void deleteByReimId(Long reimId);
}
